@@ -5,7 +5,14 @@ easy_functions是一个简单但实用的Python模块，可以通过import文件
 本模块使用MIT协议
 """
 #更新状态:活跃
-cmdlist = ['bigfont','literally','wait','cls','title','find_file','start','call','Vbs','color','mode','shield','choice','Code','mkdir','copy','pause','help','helpcmd','version','log'] #命令列表，以大写字母开头的为类(class)
+cmdlist = [
+    'bigfont','literally','wait','cls',
+    'title','find_file','start','call',
+    'Vbs','color','mode','shield',
+    'choice','Code','mkdir','copy',
+    'pause','find_suffix','help','helpcmd',
+    'version','log'
+] #命令列表，以大写字母开头的为类(class)
 __all__ = cmdlist
 c = 0
 d = 0
@@ -13,7 +20,7 @@ for i in cmdlist:
     if i.istitle():
         c += 1
 d = len(cmdlist) - c
-__version__ = str(c) + '.' + str(d) + '.' + '69' #easy_functions版本号
+__version__ = str(c) + '.' + str(d) + '.' + '77' #easy_functions版本号
 __author__ = 'Jerry\n我的QQ号：2711893794' #作者
 class FunctionSyntaxError(Exception): #异常
     def __init__(self, *error):
@@ -140,7 +147,7 @@ def literally(text, wait=0.1): #逐字显示
         wait + 1
     except TypeError as e:
         raise FunctionSyntaxError(
-            '你输入的值%s不符合运行要求，请输入数字'%wait
+            '你输入的值%s不符合运行要求，请输入数字'%type(wait)
         ) from e
     import sys, time
     sys.stdout.write("\n " + " " * 60 + "\r")
@@ -156,7 +163,7 @@ def wait(wait=1): #等待功能
         time.sleep(wait)
     except TypeError as e:
         raise FunctionSyntaxError(
-            '你输入的值%s不符合运行要求，请输入数字'%wait
+            '你输入的值%s不符合运行要求，请输入数字'%type(wait)
         ) from e
     return
 def cls(): #清除屏幕功能
@@ -199,75 +206,124 @@ def call( path ): #文件调用
     return os.system("call " + path)
 class Vbs: #创建并调用弹窗，类用法(class)
     def __init__( self ):
-        self.path = 'C:\\Users\\Administrator\\AppData\\Local\\Temp\\easy_functionsMSG.vbs'
-    def shownormal(self, title='easy_functions msgbox', message='模块easy_functions，简单，实用'): #无图标
+        import tempfile
+        self.path = tempfile.gettempdir() + '\\easy_functionsMSG.vbs'
+    def shownormal(self, title='easy_functions msgbox', message='模块easy_functions，简单，实用', *chr13): #无图标
         title = title.replace('\n','')
         message = message.replace('\n','')
         title = title.replace('\r','')
         message = message.replace('\r','')
+        true = False
+        chr = ' '
+        if len(chr13) != 0:
+            for i in chr13:
+                chr = chr + '+ chr(13) + ' + '"' + i + '"'
+            true = True
         with open(self.path,'w') as f:
             f.write('wsh.quit(msgbox(')
             f.write('"' + message + '"')
+            if true == True:
+                f.write(chr)
             f.write(',' + '0' + ',')
             f.write('"' + title + '"')
             f.write('))')
         return call(self.path)
-    def warningaskcancel(self, title='easy_functions msgbox', message='模块easy_functions，简单，实用'): #显示警告图标并提供[确认]和[取消]
+    def warningaskcancel(self, title='easy_functions msgbox', message='模块easy_functions，简单，实用', *chr13): #显示警告图标并提供[确认]和[取消]
         title = title.replace('\n','')
         message = message.replace('\n','')
         title = title.replace('\r','')
         message = message.replace('\r','')
+        true = False
+        chr = ' '
+        if len(chr13) != 0:
+            for i in chr13:
+                chr = chr + '+ chr(13) + ' + '"' + i + '"'
+            true = True
         with open(self.path,'w') as f:
             f.write('wsh.quit(msgbox(')
             f.write('"' + message + '"')
+            if true == True:
+                f.write(chr)
             f.write(',' + '49' + ',')
             f.write('"' + title + '"')
             f.write('))')
         return call(self.path)
-    def erroraskcancel(self, title='easy_functions msgbox', message='模块easy_functions，简单，实用'): #显示错误图标并提供[确认]和[取消]
+    def erroraskcancel(self, title='easy_functions msgbox', message='模块easy_functions，简单，实用', *chr13): #显示错误图标并提供[确认]和[取消]
         title = title.replace('\n','')
         message = message.replace('\n','')
         title = title.replace('\r','')
         message = message.replace('\r','')
+        true = False
+        chr = ' '
+        if len(chr13) != 0:
+            for i in chr13:
+                chr = chr + '+ chr(13) + ' + '"' + i + '"'
+            true = True
         with open(self.path,'w') as f:
             f.write('wsh.quit(msgbox(')
             f.write('"' + message + '"')
+            if true == True:
+                f.write(chr)
             f.write(',' + '17' + ',')
             f.write('"' + title + '"')
             f.write('))')
         return call(self.path)
-    def infoaskcancel(self, title='easy_functions msgbox', message='模块easy_functions，简单，实用'): #显示信息图标并提供[确认]和[取消]
+    def infoaskcancel(self, title='easy_functions msgbox', message='模块easy_functions，简单，实用', *chr13): #显示信息图标并提供[确认]和[取消]
         title = title.replace('\n','')
         message = message.replace('\n','')
         title = title.replace('\r','')
         message = message.replace('\r','')
+        true = False
+        chr = ' '
+        if len(chr13) != 0:
+            for i in chr13:
+                chr = chr + '+ chr(13) + ' + '"' + i + '"'
+            true = True
         with open(self.path,'w') as f:
             f.write('wsh.quit(msgbox(')
             f.write('"' + message + '"')
+            if true == True:
+                f.write(chr)
             f.write(',' + '65' + ',')
             f.write('"' + title + '"')
             f.write('))')
         return call(self.path)
-    def warningaskyesno(self, title='easy_functions msgbox', message='模块easy_functions，简单，实用'): #显示警告图标并提供[是]和[否]
+    def warningaskyesno(self, title='easy_functions msgbox', message='模块easy_functions，简单，实用', *chr13): #显示警告图标并提供[是]和[否]
         title = title.replace('\n','')
         message = message.replace('\n','')
         title = title.replace('\r','')
         message = message.replace('\r','')
+        true = False
+        chr = ' '
+        if len(chr13) != 0:
+            for i in chr13:
+                chr = chr + '+ chr(13) + ' + '"' + i + '"'
+            true = True
         with open(self.path,'w') as f:
             f.write('wsh.quit(msgbox(')
             f.write('"' + message + '"')
+            if true == True:
+                f.write(chr)
             f.write(',' + '52' + ',')
             f.write('"' + title + '"')
             f.write('))')
         return call(self.path)
-    def errorretry(self, title='easy_functions msgbox', message='模块easy_functions，简单，实用'): #显示错误图标并提供[重试]和[取消]
+    def errorretry(self, title='easy_functions msgbox', message='模块easy_functions，简单，实用', *chr13): #显示错误图标并提供[重试]和[取消]
         title = title.replace('\n','')
         message = message.replace('\n','')
         title = title.replace('\r','')
         message = message.replace('\r','')
+        true = False
+        chr = ' '
+        if len(chr13) != 0:
+            for i in chr13:
+                chr = chr + '+ chr(13) + ' + '"' + i + '"'
+            true = True
         with open(self.path,'w') as f:
             f.write('wsh.quit(msgbox(')
             f.write('"' + message + '"')
+            if true == True:
+                f.write(chr)
             f.write(',' + '21' + ',')
             f.write('"' + title + '"')
             f.write('))')
@@ -310,41 +366,22 @@ def color( color ): #更改颜色
 def mode(cols, lines): #更改cmd外框大小
     import os
     try:
-        cols + 1
-    except TypeError as e:
-        try:
-            int(cols) + 1
-        except ValueError as e:
-            raise FunctionSyntaxError(
-                '请不要输入除数字外的字母，符号等'
-            ) from e
-            return
-        else:
-            c = cols
-    else:
+        int(str(cols))
+    except ValueError as e:
         raise FunctionSyntaxError(
-            '该功能需要输入字符串，而你输入了数字'
+            '请不要输入除数字外的字母，符号等'
         ) from e
-        return
+    else:
+        c = str(cols)
     try:
-        lines + 1
-    except TypeError as e:
-        try:
-            int(lines) + 1
-        except ValueError as e:
-            raise FunctionSyntaxError(
-                '请不要输入除数字外的字母，符号等'
-            ) from e
-            return
-        else:
-            l = lines
-    else:
+        int(str(lines))
+    except ValueError as e:
         raise FunctionSyntaxError(
-            '该功能需要输入字符串，而你输入了数字'
+            '请不要输入除数字外的字母，符号等'
         ) from e
-        return
-    os.system('mode con cols=' + c + ' lines=' + l)
-    return
+    else:
+        l = str(lines)
+    return os.system('mode con cols=' + c + ' lines=' + l)
 def shield(words, WordsBlackList): #词语屏蔽
     A_list = ['*','**','***','****','*****','******','*******','********','*********','**********','***********','************']
     try:
@@ -404,16 +441,45 @@ def mkdir( path ): #新建文件夹
     return os.system('mkdir ' + path)
 def copy(filein, fileout): #文件复制功能
     import os
-    if not find_file(filein):
+    if not find_file(filein,'exist?'):
         raise FileNotFoundError(
             '没有名为%s的文件'%filein
         )
     return os.system('copy ' + filein + ' ' + fileout + ' ' + '>nul')
-def pause(text='请按任意键继续...'): #文件删除功能
+def pause(text='请按任意键继续...'): #暂停功能
     import os
     print(text)
     os.system('pause >nul')
     return
+def find_suffix(path, suffix): #查找指定后缀的文件
+    import os
+    file_list = []
+    for i in path:
+        if i == ' ':
+            raise FunctionSyntaxError(
+                '\n路径\n"%s"\n中含有空格'%path
+            )
+    for i in suffix:
+        if i == ' ':
+            raise FunctionSyntaxError(
+                '后缀"%s"中含有空格'%suffix
+            )
+    if not suffix[0] == '.' or '.' in suffix[1:]:
+        raise FunctionSyntaxError(
+            '你的后缀"%s"无效，请输入例如".py"一类的后缀'%suffix
+        )
+    with open('C:\\Users\\Administrator\\AppData\\Local\\Temp\\make_file_list.bat','w',encoding='ansi') as f:
+        f.write('@echo off\n')
+        f.write('for /r ' + path + ' %%r in (*' + suffix + ') do (\n')
+        f.write('    echo %%r >>%tmp%\maker.tmp\n')
+        f.write(')')
+    call('C:\\Users\\Administrator\\AppData\\Local\\Temp\\make_file_list.bat >nul')
+    os.remove('C:\\Users\\Administrator\\AppData\\Local\\Temp\\make_file_list.bat')
+    with open('C:\\Users\\Administrator\\AppData\\Local\\Temp\\maker.tmp','r') as f:
+        for i in f.readlines():
+            file_list.append(i.replace('\n',''))
+    os.remove('C:\\Users\\Administrator\\AppData\\Local\\Temp\\maker.tmp')
+    return file_list
 def log(): #更新日志
     print('')
     print('作者决定，从2021-3-21起开始记录本模块的更新')
@@ -430,7 +496,7 @@ def log(): #更新日志
     print("1.修改了功能Vbs的使用方法，不再强制需要使用(title='标题',text='正文')的写法了，同时该功能的语法发生改变，具体请使用helpcmd()功能查看")
     print('')
     print('[2021-3-28] [2条更新]')
-    print('1.修改了功能Code的用法，具体使用helpcmd()查看')
+    print('1.修改了功能Code的用法，具体请使用helpcmd()查看')
     print('2.添加了在用户直接打开文件而不是调用文件的时候，将运行help()')
     print('')
     print('[2021-4-3] [1条更新]')
@@ -448,7 +514,7 @@ def log(): #更新日志
     print('')
     print('[2021-4-25] [2条更新]')
     print('1.更改命令名称"testfor"为"find_file"')
-    print('2.对find_file功能进行了更改，现在调用文件时不会再生成ErrorOutPut.log文件，而是返回布尔值，可以直接储存在变量中')
+    print('2.对功能find_file进行了更改，现在调用文件时不会再生成ErrorOutPut.log文件，而是返回布尔值，可以直接储存在变量中')
     print('')
     print('[2021-4-30] [1条更新]')
     print('1.在功能choice中添加了位置参数hide，需要输入布尔值来操作')
@@ -457,7 +523,7 @@ def log(): #更新日志
     print('1.将功能choice中的位置参数hide由位置参数改为命名关键字')
     print('')
     print('[2021-5-4] [1条更新]')
-    print('1.更新了choice功能的帮助文字')
+    print('1.更新了功能choice的帮助文字')
     print('')
     print('[2021-5-5] [1条更新]')
     print('1.在功能choice中增加了一条检测语句，现在显示的文字中含有空格将会报错')
@@ -466,7 +532,7 @@ def log(): #更新日志
     print('1.因为PyPi官网的重名，本模块由pymod更名为SimpleFunctions')
     print('')
     print('[2021-5-7] [1条更新]')
-    print('1.对start功能进行了微调')
+    print('1.对功能start进行了微调')
     print('')
     print('[2021-5-8] [1条更新]')
     print('1.在功能choice中增加了一条检测语句，现在按键默认值不在设置的按键中将会报错')
@@ -475,7 +541,7 @@ def log(): #更新日志
     print('1.更改了功能choice中位置参数default和time的默认值')
     print('')
     print('[2021-5-18] [1条更新]')
-    print('1.增加了copy功能，具体请使用helpcmd()查看')
+    print('1.增加了功能copy，具体请使用helpcmd()查看')
     print('')
     print('[2021-5-19] [1条更新]')
     print('1.在功能literally中增加了一条检测语句，在用户没有赋值位置参数wait为数字时将会报错')
@@ -507,8 +573,33 @@ def log(): #更新日志
     print('1.升级了功能find_file，使得此功能可以判断文件是否可以被导入')
     print('2.在功能find_file中增加了一个位置参数，使得此功能拥有两个模式，具体请使用helpcmd()查看')
     print('')
-    print('[2021-6-21] [1条更新]')
+    print('[2021-6-21] [2条更新]')
     print('1.在功能find_file中添加了一条if语句，使用户没有输入字符串时报错')
+    print('2.对功能wait和功能literally的报错进行了优化')
+    print('')
+    print('[2021-7-1] [1条更新]')
+    print('1.增加了find_suffix功能，具体请使用helpcmd()查看')
+    print('')
+    print('[2021-7-3] [1条更新]')
+    print('1.对功能find_suffix的报错进行了优化')
+    print('')
+    print('[2021-7-4] [1条更新]')
+    print('1.修复了功能copy因功能find_file的语法改变而不可使用的bug')
+    print('')
+    print('[2021-7-5] [1条更新]')
+    print('1.功能Vbs的弹窗正文现在支持换行，不过不是用换行符，具体请使用helpcmd()查看')
+    print('')
+    print('[2021-7-7] [1条更新]')
+    print('1.修复了功能mode的一些bug')
+    print('')
+    print('[2021-7-16] [1条更新]')
+    print('1.优化了功能mode，使其参数可以传入数字或由数字组成的字符串')
+    print('')
+    print('[2021-8-13][GitHub][1条更新]')
+    print('1.增加了GitHub页面')
+    print('')
+    print('[2021-8-18][1条更新]')
+    print('1.修复了功能Vbs因临时文件夹路径的问题而无法使用的bug')
     print('')
     return
 def version(): #版本
@@ -580,7 +671,21 @@ def helpcmd( cmd ): #文件命令功能解释
     if cmd == 'Vbs':
         print('<',cmd,'>','弹窗创建功能')
         print("用法：变量 = 文件名或<import...as...>命令别名.Vbs()")
-        print("      变量.shownormal('标题','正文')/warningaskcancel('标题','正文')/erroraskcancel('标题','正文')/...")
+        print("      变量.shownormal('标题','正文','换行文字')/warningaskcancel('标题','正文','换行文字')/erroraskcancel('标题','正文','换行文字')/...")
+        print('如果想要换行，可以这样：')
+        print('import easy_functions as ef')
+        print('v = ef.Vbs()')
+        print("v.shownormal('a','b','c','d')")
+        print('其中，"a"为标题，"b"为正文，"c"和"d"将被换行')
+        print('它看上去应该是这样子的(弹窗位置演示)：')
+        print('')
+        print('标题处：      |--a------|')
+        print('正文处：      |    b    |')
+        print('换行的正文：  |    c    |')
+        print('换行的正文：  |    d    |')
+        print('按键处：      |----确定-|')
+        print('')
+        print('换行文字支持无限个，相当于在tkinter的弹窗中使用换行符')
         print('注意：模块tkinter中含有的图标类型以及按键本模块不再编写，请使用模块tkinter')
         print('      用户按下Vbs提供的按键后会返回数字，可根据数字判断用户按下的按键')
         print('      请自行调试返回值，每个按键的返回值这里不予提供')
@@ -613,17 +718,18 @@ def helpcmd( cmd ): #文件命令功能解释
         return
     if cmd == 'mode':
         print('<',cmd,'>','cmd外框大小修改功能')
-        print("用法：文件名或<import...as...>命令别名.mode('宽','高')")
+        print('用法：文件名或<import...as...>命令别名.mode(宽, 高)')
+        print('宽和高需要输入数字，也可以输入字符串，但字符串必须由数字组成')
         return
     if cmd == 'shield':
         print('<',cmd,'>','词语屏蔽功能')
         print('用法：先新建一个列表，例如blacklist')
         print("用法：文件名或<import...as...>命令别名.shield('句子',blacklist)")
-        print("将会把句子中出现在blacklist中的词语全部替换为'*'")
+        print('将会把句子中出现在blacklist中的词语全部替换为"*"')
         return
     if cmd == 'choice':
         print('<',cmd,'>','按键选择功能')
-        print("用法：文件名或<import...as...>命令别名.choice('用户可选的按键','显示的文字','默认按键选择(可填)','多少秒后默认按键生效(必须先指定默认按键，默认为0)'),'hide=True/False #是否隐藏选项列表)'")
+        print("用法：文件名或<import...as...>命令别名.choice('用户可选的按键','显示的文字','默认按键选择(可填)','多少秒后默认按键生效(必须先指定默认按键，默认为0)'),'hide=True/False 是否隐藏选项列表)'")
         print('显示的文字中不能含有空格')
         print('可以写成：变量 = 文件名或<import...as...>命令别名.choice()')
         print('如果这样写，用户所选择的按键就会变为返回值存储在变量中')
@@ -665,6 +771,11 @@ def helpcmd( cmd ): #文件命令功能解释
         print("用法：文件名或<import...as...>命令别名.pause('显示的文字')")
         print("这个命令和使用input('显示的文字')的区别是input()是pause()只需要按下键盘上的任意按键，而input()需要按下回车")
         return
+    if cmd == 'find_suffix':
+        print('<',cmd,'>','后缀查找功能')
+        print("用法：文件名或<import...as...>命令别名.find_suffix('文件夹路径','后缀')")
+        print('将遍历文件夹中所有指定后缀的文件，以列表形式返回')
+        return
     if cmd == 'log':
         print('<',cmd,'>','更新日志查看功能')
         print('更新日志从2021-3-21开始记录')
